/* GitHub Light Mode Styles */
body {
    font-family: Arial, sans-serif;
    background-color: #ffffff;
    color: #24292e;
    margin: 0;
    padding: 20px;
    line-height: 1.5;
}

a {
    color: #0366d6;
    text-decoration: none;
}

a:hover {
    text-decoration: underline;
}

h1,
h2,
h3 {
    margin-top: 1.5em;
}

h1 {
    font-size: 28px;
    border-bottom: 1px solid #e1e4e8;
}

h2 {
    font-size: 24px;
}

h3 {
    font-size: 20px;
}

img {
    max-width: 100%;
    display: block;
    margin: 20px 0;
}

pre {
    background-color: #f6f8fa;
    padding: 15px;
    border-radius: 6px;
    overflow-x: auto;
}

code {
    font-family: monospace;
    background-color: #f6f8fa;
    padding: 2px 5px;
    border-radius: 4px;
    border: 1px solid #d1d5da;
}

ul,
ol {
    margin-left: 20px;
}

/* GitHub-inspired Light Theme for highlight.js */

.hljs {
    display: block;
    overflow-x: auto;
    padding: 0.5em;
    background: #f6f8fa;
    border: none;
    outline: none;
}

/* For built-ins, tags, and links */
.hljs-built_in,
.hljs-selector-tag,
.hljs-section,
.hljs-link {
    color: #005cc5;
    /* GitHub blue */
}

/* Keywords */
.hljs-keyword {
    color: #d73a49;
    /* GitHub red */
}

/* Regular text and substitutions */
.hljs,
.hljs-subst {
    color: #24292e;
    /* GitHub dark text */
}

/* Titles, attributes, and meta keywords */
.hljs-title,
.hljs-attr,
.hljs-meta-keyword {
    font-style: italic;
    color: #6f42c1;
    /* GitHub purple */
}

/* Strings, meta, and names */
.hljs-string,
.hljs-meta,
.hljs-name {
    color: #032f62;
    /* GitHub dark blue */
}

/* Types, symbols, and bullets */
.hljs-type,
.hljs-symbol,
.hljs-bullet {
    color: #22863a;
    /* GitHub green */
}

/* Variables and template tags/variables */
.hljs-variable,
.hljs-template-tag,
.hljs-template-variable {
    color: #e36209;
    /* GitHub orange */
}

/* Comments and quotes */
.hljs-comment,
.hljs-quote {
    color: #6a737d;
    /* GitHub gray */
}

/* Bold elements */
.hljs-keyword,
.hljs-selector-tag,
.hljs-literal,
.hljs-title,
.hljs-section,
.hljs-doctag,
.hljs-type,
.hljs-name,
.hljs-strong {
    font-weight: bold;
}

/* Numbers */
.hljs-literal,
.hljs-number {
    color: #005cc5;
    /* GitHub blue */
}

/* Emphasis */
.hljs-emphasis {
    font-style: italic;
}